summaryrefslogtreecommitdiff
path: root/src/macros.rs
diff options
context:
space:
mode:
authorYuki Okushi <yuki.okushi@huawei.com>2021-11-16 09:46:34 +0900
committerYuki Okushi <yuki.okushi@huawei.com>2021-11-16 09:46:34 +0900
commitefc0a9eb9c4663ed970d6a3cd23b229c8317fc32 (patch)
tree6e9d2b81a39ec032d0b7d3d894f98c4dec6a277c /src/macros.rs
parent3e36a07c8b61ce95ee41ad260e33ab1cbb74971e (diff)
downloadrust-libc-efc0a9eb9c4663ed970d6a3cd23b229c8317fc32.tar.gz
Suggest the `mach2` crate instead
Diffstat (limited to 'src/macros.rs')
-rw-r--r--src/macros.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/macros.rs b/src/macros.rs
index d52c4ad81e..9fb7f7a70c 100644
--- a/src/macros.rs
+++ b/src/macros.rs
@@ -307,13 +307,13 @@ macro_rules! align_const {
)*)
}
// This macro is used to deprecate items that should be accessed via the mach crate
#[allow(unused_macros)]
macro_rules! deprecated_mach {
(pub const $id:ident: $ty:ty = $expr:expr;) => {
#[deprecated(
since = "0.2.55",
- note = "Use the `mach` crate instead",
+ note = "Use the `mach2` crate instead",
)]
#[allow(deprecated)]
pub const $id: $ty = $expr;
@@ -328,7 +328,7 @@ macro_rules! deprecated_mach {
(pub type $id:ident = $ty:ty;) => {
#[deprecated(
since = "0.2.55",
- note = "Use the `mach` crate instead",
+ note = "Use the `mach2` crate instead",
)]
#[allow(deprecated)]
pub type $id = $ty;
@@ -307,13 +307,13 @@ macro_rules! align_const {
)*)
}
-// This macro is used to deprecate items that should be accessed via the mach crate
+// This macro is used to deprecate items that should be accessed via the mach2 crate
#[allow(unused_macros)]
macro_rules! deprecated_mach {